@@ -1,18 +1,16 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 """PyBluez example read_name.py
 
 Copyright (C) 2014, Oscar Acena <oscaracena@gmail.com>
 This software is under the terms of GPLv3 or later.
 """
 
-from __future__ import print_function  # Python 2 compatibility
 import sys
 
 from bluetooth.ble import GATTRequester
 
 
-class Reader(object):
+class Reader:
 
     def __init__(self, address):
         self.requester = GATTRequester(address, False)
