@@ -1,5 +1,4 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 """PyBluez simple example l2capclient.py
 
 Demo L2CAP client for bluetooth module.
@@ -11,11 +10,6 @@ import sys
 
 import bluetooth
 
-# Python 2 compatibility
-try:
-    input = raw_input
-except NameError:
-    pass  # Python 3
 
 sock = bluetooth.BluetoothSocket(bluetooth.L2CAP)
 
