@@ -1,5 +1,4 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 """PyBluez simple example rfcomm-client.py
 
 Simple demonstration of a client application that uses RFCOMM sockets intended
@@ -13,11 +12,6 @@ import sys
 
 import bluetooth
 
-# Python 2 compatibility
-try:
-    input = raw_input
-except NameError:
-    pass  # Python 3
 
 addr = None
 
