@@ -5,7 +5,6 @@
 #include <BtIfClasses.h>
 #include <com_error.h>
 #include "util.h"
-#include <port3.h>
 
 #include "inquirer.hpp"
 
@@ -23,7 +22,7 @@ static void
 dict_set_str_pyobj(PyObject *dict, const char *key, PyObject *valobj)
 {
     PyObject *keyobj;
-    keyobj = PyString_FromString (key);
+    keyobj = PyUnicode_FromString (key);
     PyDict_SetItem (dict, keyobj, valobj);
     Py_DECREF (keyobj);
 }
@@ -32,8 +31,8 @@ static void
 dict_set_strings(PyObject *dict, const char *key, const char *val)
 {
     PyObject *keyobj, *valobj;
-    keyobj = PyString_FromString (key);
-    valobj = PyString_FromString (val);
+    keyobj = PyUnicode_FromString (key);
+    valobj = PyUnicode_FromString (val);
     PyDict_SetItem (dict, keyobj, valobj);
     Py_DECREF (keyobj);
     Py_DECREF (valobj);
@@ -43,8 +42,8 @@ static void
 dict_set_str_long(PyObject *dict, const char *key, long val)
 {
     PyObject *keyobj, *valobj;
-    keyobj = PyString_FromString (key);
-    valobj = PyInt_FromLong(val);
+    keyobj = PyUnicode_FromString (key);
+    valobj = PyLong_FromLong(val);
     PyDict_SetItem (dict, keyobj, valobj);
     Py_DECREF (keyobj);
     Py_DECREF (valobj);
@@ -216,14 +215,14 @@ static PyObject *
 get_sockport (PyObject *s)
 {
     WCInquirerPyObject *self = (WCInquirerPyObject*) s;
-    return PyInt_FromLong (self->inq->GetSockPort ());
+    return PyLong_FromLong (self->inq->GetSockPort ());
 }
 
 static PyObject *
 accept_client (PyObject *s)
 {
     WCInquirerPyObject *self = (WCInquirerPyObject*) s;
-    return PyInt_FromLong (self->inq->AcceptClient ());
+    return PyLong_FromLong (self->inq->AcceptClient ());
 }
 
 static PyObject * 
@@ -303,7 +302,7 @@ get_local_device_name (PyObject *s)
     WCInquirerPyObject *self = (WCInquirerPyObject*) s;
     BD_NAME name;
     if (self->inq->GetLocalDeviceName (&name)) {
-        return PyString_FromString ( (const char *)name);
+        return PyUnicode_FromString ( (const char *)name);
     } else {
         Py_RETURN_NONE;
     }
@@ -441,7 +440,7 @@ read_discovery_records (PyObject *s, PyObject *args)
 //                            u[8], u[9], u[10], u[11],
 //                            u[12], u[13], u[14], u[15]);
 //                    printf ("%s\n", buf);
-//                    PyObject *uuid_pyobj = PyString_FromString (buf);
+//                    PyObject *uuid_pyobj = PyUnicode_FromString (buf);
 //                    PyList_Append (uuid_list, uuid_pyobj);
 //                    Py_DECREF (uuid_pyobj);
 //                } else {
@@ -493,7 +492,7 @@ get_btw_version_info (PyObject *s)
     char buf[MAX_PATH];
     BOOL result = self->inq->GetBTWVersionInfo (buf, MAX_PATH);
     if (result) {
-        return PyString_FromString (buf);
+        return PyUnicode_FromString (buf);
     } else {
         Py_RETURN_NONE;
     }
@@ -526,7 +525,7 @@ static PyMethodDef wcinquirer_methods[] = {
 static PyObject *
 wcinquirer_repr(WCInquirerPyObject *s)
 {
-    return PyString_FromString("_WCInquirer object");
+    return PyUnicode_FromString("_WCInquirer object");
 }
 
 static PyObject *
@@ -564,12 +563,7 @@ wcinquirer_initobj(PyObject *s, PyObject *args, PyObject *kwds)
 
 /* Type object for socket objects. */
 PyTypeObject wcinquirer_type = {
-#if PY_MAJOR_VERSION < 3
-    PyObject_HEAD_INIT(0)   /* Must fill in type value later */
-    0,                  /* ob_size */
-#else
     PyVarObject_HEAD_INIT(NULL, 0)   /* Must fill in type value later */
-#endif
     "_widcomm._WCInquirer",            /* tp_name */
     sizeof(WCInquirerPyObject),     /* tp_basicsize */
     0,                  /* tp_itemsize */
