@@ -4,7 +4,6 @@
 #include <BtIfDefinitions.h>
 #include <BtIfClasses.h>
 #include <com_error.h>
-#include <port3.h>
 
 #include "rfcommport.hpp"
 
@@ -133,14 +132,14 @@ static PyObject *
 get_sockport (PyObject *s)
 {
     WCRfCommPortPyObject *self = (WCRfCommPortPyObject*) s;
-    return PyInt_FromLong (self->rfcp->GetSockPort ());
+    return PyLong_FromLong (self->rfcp->GetSockPort ());
 }
 
 static PyObject *
 accept_client (PyObject *s)
 {
     WCRfCommPortPyObject *self = (WCRfCommPortPyObject*) s;
-    return PyInt_FromLong (self->rfcp->AcceptClient ());
+    return PyLong_FromLong (self->rfcp->AcceptClient ());
 }
 
 static PyObject *
@@ -155,7 +154,7 @@ wc_open_server (PyObject *s, PyObject *args)
     CRfCommPort::PORT_RETURN_CODE result = 
         self->rfcp->OpenServer (scn, desired_mtu);
 
-    return PyInt_FromLong (result);
+    return PyLong_FromLong (result);
 }
 
 static PyObject *
@@ -185,7 +184,7 @@ wc_open_client (PyObject *s, PyObject *args)
     result = self->rfcp->OpenClient (scn, bdaddr, desired_mtu);
     Py_END_ALLOW_THREADS;
 
-    return PyInt_FromLong (result);
+    return PyLong_FromLong (result);
 }
 
 static PyObject *
@@ -213,18 +212,18 @@ static PyObject *
 wc_set_flow_enabled (PyObject *s, PyObject *arg)
 {
     _WCRfCommPortPyObject *self = (_WCRfCommPortPyObject*) s;
-    int enable = PyInt_AsLong (arg);
+    int enable = PyLong_AsLong (arg);
     CRfCommPort::PORT_RETURN_CODE result = self->rfcp->SetFlowEnabled (enable);
-    return PyInt_FromLong (result);
+    return PyLong_FromLong (result);
 }
 
 static PyObject *
 wc_set_modem_signal (PyObject *s, PyObject *arg)
 {
     _WCRfCommPortPyObject *self = (_WCRfCommPortPyObject*) s;
-    UINT8 signal = static_cast <UINT8> (PyInt_AsLong (arg));
+    UINT8 signal = static_cast <UINT8> (PyLong_AsLong (arg));
     CRfCommPort::PORT_RETURN_CODE result = self->rfcp->SetModemSignal (signal);
-    return PyInt_FromLong (result);
+    return PyLong_FromLong (result);
 }
 
 static PyObject *
@@ -240,18 +239,18 @@ static PyObject *
 wc_send_error (PyObject *s, PyObject *arg)
 {
     _WCRfCommPortPyObject *self = (_WCRfCommPortPyObject*) s;
-    UINT8 errors = static_cast <UINT8> (PyInt_AsLong (arg));
+    UINT8 errors = static_cast <UINT8> (PyLong_AsLong (arg));
     CRfCommPort::PORT_RETURN_CODE result = self->rfcp->SendError (errors);
-    return PyInt_FromLong (result);
+    return PyLong_FromLong (result);
 }
 
 static PyObject *
 wc_purge (PyObject *s, PyObject *arg)
 {
     _WCRfCommPortPyObject *self = (_WCRfCommPortPyObject*) s;
-    UINT8 purge_flags = static_cast <UINT8> (PyInt_AsLong (arg));
+    UINT8 purge_flags = static_cast <UINT8> (PyLong_AsLong (arg));
     CRfCommPort::PORT_RETURN_CODE result = self->rfcp->Purge (purge_flags);
-    return PyInt_FromLong (result);
+    return PyLong_FromLong (result);
 }
 
 static PyObject *
@@ -295,19 +294,19 @@ wc_switch_role (PyObject *s, PyObject *arg)
 {
     _WCRfCommPortPyObject *self = (_WCRfCommPortPyObject*) s;
     MASTER_SLAVE_ROLE new_role = 
-        static_cast <MASTER_SLAVE_ROLE> (PyInt_AsLong (arg));
+        static_cast <MASTER_SLAVE_ROLE> (PyLong_AsLong (arg));
     BOOL result = self->rfcp->SwitchRole (new_role);
-    return PyInt_FromLong (result);
+    return PyLong_FromLong (result);
 }
 
 static PyObject *
 wc_set_link_supervision_timeout (PyObject *s, PyObject *arg)
 {
     _WCRfCommPortPyObject *self = (_WCRfCommPortPyObject*) s;
-    UINT16 timeoutSlot = static_cast <UINT16> (PyInt_AsLong (arg));
+    UINT16 timeoutSlot = static_cast <UINT16> (PyLong_AsLong (arg));
     CRfCommPort::PORT_RETURN_CODE result = 
         self->rfcp->SetLinkSupervisionTimeOut (timeoutSlot);
-    return PyInt_FromLong (result);
+    return PyLong_FromLong (result);
 }
 
 static PyMethodDef wcrfcommport_methods[] = {
@@ -334,7 +333,7 @@ static PyMethodDef wcrfcommport_methods[] = {
 static PyObject *
 wcrfcommport_repr(WCRfCommPortPyObject *s)
 {
-    return PyString_FromString("_WCRfCommPort object");
+    return PyUnicode_FromString("_WCRfCommPort object");
 }
 
 static PyObject *
@@ -371,12 +370,7 @@ wcrfcommport_initobj(PyObject *s, PyObject *args, PyObject *kwds)
 
 /* Type object for socket objects. */
 PyTypeObject wcrfcommport_type = {
-#if PY_MAJOR_VERSION < 3
-    PyObject_HEAD_INIT(0)   /* Must fill in type value later */
-    0,                  /* ob_size */
-#else
     PyVarObject_HEAD_INIT(NULL, 0)   /* Must fill in type value later */
-#endif
     "_widcomm._WCRfCommPort",            /* tp_name */
     sizeof(WCRfCommPortPyObject),     /* tp_basicsize */
     0,                  /* tp_itemsize */
